@@ -22,10 +22,14 @@ std::vector<algorithm> get_algos()
    algos.push_back(algorithm("Block Cipher", "GOST", "GOST/ECB", 32));
    algos.push_back(algorithm("Block Cipher", "IDEA", "IDEA/ECB", 16));
    algos.push_back(algorithm("Block Cipher", "KASUMI", "KASUMI/ECB", 16));
-   algos.push_back(algorithm("Block Cipher", "Lion(MD5,WiderWake4+1)",
-             "Lion(MD5,WiderWake4+1-BE,65536)/ECB", 20));
-   algos.push_back(algorithm("Block Cipher", "Luby-Rackoff(SHA-1)",
-             "Luby-Rackoff(SHA-1)/ECB", 16));
+
+   algos.push_back(algorithm("Block Cipher",
+                             "Lion(SHA-256,Turing)",
+                             "Lion(SHA-256,Turing,8192)/ECB", 32));
+
+   algos.push_back(algorithm("Block Cipher", "Luby-Rackoff(SHA-512)",
+                             "Luby-Rackoff(SHA-512)/ECB", 16));
+
    algos.push_back(algorithm("Block Cipher", "MARS", "MARS/ECB", 32));
    algos.push_back(algorithm("Block Cipher", "MISTY1", "MISTY1/ECB", 16));
    algos.push_back(algorithm("Block Cipher", "Noekeon", "Noekeon/ECB", 16));
@@ -43,6 +47,9 @@ std::vector<algorithm> get_algos()
    algos.push_back(algorithm("Block Cipher", "Twofish", "Twofish/ECB", 32));
    algos.push_back(algorithm("Block Cipher", "XTEA", "XTEA/ECB", 16));
 
+   algos.push_back(algorithm("Cipher Mode", "DES/CBC/PKCS7", 8, 8));
+   algos.push_back(algorithm("Cipher Mode", "TripleDES/CBC/PKCS7", 24, 8));
+
    algos.push_back(algorithm("Cipher Mode", "AES-128/CBC/PKCS7", 16, 16));
    algos.push_back(algorithm("Cipher Mode", "AES-128/CBC/CTS", 16, 16));
    algos.push_back(algorithm("Cipher Mode", "AES-128/CFB(128)", 16, 16));
@@ -56,6 +63,7 @@ std::vector<algorithm> get_algos()
    algos.push_back(algorithm("Cipher Mode", "AES-128/EAX", 16, 16));
 
    algos.push_back(algorithm("Stream Cipher", "ARC4", 16));
+   algos.push_back(algorithm("Stream Cipher", "Salsa20", 32));
    algos.push_back(algorithm("Stream Cipher", "Turing", 32));
    algos.push_back(algorithm("Stream Cipher", "WiderWake4+1",
                              "WiderWake4+1-BE", 16, 8));
@@ -82,6 +90,8 @@ std::vector<algorithm> get_algos()
    algos.push_back(algorithm("MAC", "HMAC(SHA-1)", 16));
    algos.push_back(algorithm("MAC", "X9.19-MAC", 16));
 
+   algos.push_back(algorithm("RNG", "AutoSeeded", 4096));
+   algos.push_back(algorithm("RNG", "HMAC_RNG", 4096));
    algos.push_back(algorithm("RNG", "Randpool", 4096));
    algos.push_back(algorithm("RNG", "X9.31-RNG", 4096));
 
