@@ -18,10 +18,8 @@ This file is in the public domain
 
 #include <botan/botan.h>
 
-#if defined(BOTAN_EXT_COMPRESSOR_ZLIB)
+#if defined(BOTAN_HAS_COMPRESSOR_ZLIB)
   #include <botan/zlib.h>
-#else
-  #error "You didn't compile the zlib module into Botan"
 #endif
 
 using namespace Botan;
@@ -112,7 +110,9 @@ int main(int argc, char* argv[])
 
       Pipe pipe(new Base64_Decoder,
                 get_cipher(algo + "/CBC", bc_key, iv, DECRYPTION),
+#ifdef BOTAN_HAS_COMPRESSOR_ZLIB
                 new Zlib_Decompression,
+#endif
                 new Fork(
                    0,
                    new Chain(new MAC_Filter("HMAC(SHA-1)", mac_key),
