@@ -48,11 +48,10 @@ int main(int argc, char* argv[])
          return 1;
          }
 
-      std::auto_ptr<RandomNumberGenerator> rng(
-         RandomNumberGenerator::make_rng());
+      AutoSeeded_RNG rng;
 
       std::auto_ptr<PKCS8_PrivateKey> key(
-         PKCS8::load_key(argv[1], *rng, passphrase)
+         PKCS8::load_key(argv[1], rng, passphrase)
          );
 
       DSA_PrivateKey* dsakey = dynamic_cast<DSA_PrivateKey*>(key.get());
@@ -63,7 +62,7 @@ int main(int argc, char* argv[])
          return 1;
          }
 
-      PK_Signer signer(*dsakey, "EMSA1(SHA-1)");
+      PK_Signer signer(*dsakey, get_emsa("EMSA1(SHA-1)"));
 
       DataSource_Stream in(message);
       byte buf[4096] = { 0 };
@@ -71,7 +70,7 @@ int main(int argc, char* argv[])
          signer.update(buf, got);
 
       Pipe pipe(new Base64_Encoder);
-      pipe.process_msg(signer.signature(*rng));
+      pipe.process_msg(signer.signature(rng));
       sigfile << pipe.read_all_as_string() << std::endl;
    }
    catch(std::exception& e)
