@@ -26,10 +26,8 @@ This file is in the public domain
 
 #include <botan/botan.h>
 
-#if defined(BOTAN_EXT_COMPRESSOR_ZLIB)
+#if defined(BOTAN_HAS_COMPRESSOR_ZLIB)
   #include <botan/zlib.h>
-#else
-  #error "You didn't compile the zlib module into Botan"
 #endif
 
 using namespace Botan;
@@ -121,12 +119,11 @@ int main(int argc, char* argv[])
       const u32bit key_len = max_keylength_of(algo);
       const u32bit iv_len = block_size_of(algo);
 
-      std::auto_ptr<RandomNumberGenerator> rng(
-         RandomNumberGenerator::make_rng());
+      AutoSeeded_RNG rng;
 
       std::auto_ptr<S2K> s2k(get_s2k("PBKDF2(SHA-1)"));
       s2k->set_iterations(8192);
-      s2k->new_random_salt(*rng, 8);
+      s2k->new_random_salt(rng, 8);
 
       SymmetricKey bc_key = s2k->derive_key(key_len, "BLK" + passphrase);
       InitializationVector iv = s2k->derive_key(iv_len, "IVL" + passphrase);
@@ -141,7 +138,10 @@ int main(int argc, char* argv[])
                    new Chain(new MAC_Filter("HMAC(SHA-1)", mac_key),
                              new Base64_Encoder
                       ),
-                   new Chain(new Zlib_Compression,
+                   new Chain(
+#ifdef BOTAN_HAS_COMPRESSOR_ZLIB
+                             new Zlib_Compression,
+#endif
                              get_cipher(algo + "/CBC", bc_key, iv, ENCRYPTION),
                              new Base64_Encoder(true)
                       )
