@@ -42,13 +42,12 @@ int main(int argc, char* argv[])
 
    try
       {
-      std::auto_ptr<RandomNumberGenerator> rng(
-         RandomNumberGenerator::make_rng());
+      AutoSeeded_RNG rng;
 
-      RSA_PrivateKey key(*rng, 1024);
+      RSA_PrivateKey key(rng, 1024);
 
       std::ofstream priv_key("private.pem");
-      priv_key << PKCS8::PEM_encode(key, *rng, argv[1]);
+      priv_key << PKCS8::PEM_encode(key, rng, argv[1]);
 
       X509_Cert_Options opts;
 
@@ -63,7 +62,7 @@ int main(int argc, char* argv[])
       if(do_CA)
          opts.CA_key();
 
-      X509_Certificate cert = X509::create_self_signed_cert(opts, key, *rng);
+      X509_Certificate cert = X509::create_self_signed_cert(opts, key, rng);
 
       std::ofstream cert_file("cert.pem");
       cert_file << cert.PEM_encode();
